// Copyright 2022 The Kubernetes Authors.
// SPDX-License-Identifier: Apache-2.0

package repo

import (
	"testing"
)

func TestLoadRepoManager(t *testing.T) {
	t.Skip()
}
